#!/bin/sh
#-----------------------------------------------------------#
# install.sh: 
#-----------------------------------------------------------#
# 処理概要: intelドライバおよび関連パッケージのインストール
#-----------------------------------------------------------#
# 引数: なし
#-----------------------------------------------------------#
# 2009/2/20 SoSO
#-----------------------------------------------------------#

#-----------------------------------------------------------#
# 設定
#-----------------------------------------------------------#
# intel の G45 チップセットが増設されているかどうかを判別する文字列
# (lspci の出力を検索します。大文字小文字は関係ありません）
G45_flg='Eaglelake Integrated Graphics Controller'

#-----------------------------------------------------------#
# 前処理
#-----------------------------------------------------------#
cd $(dirname $0)
SCRPT_HOME=$(pwd)

# 共通設定ファイルの読み込み
COMMON_SH=$SCRPT_HOME/common.sh
if [ -f $COMMON_SH ]; then
	. $COMMON_SH
else
	echo "[エラー] ${COMMON_SH} が存在しません。"
	exit 1
fi

# ログ
LOG=$_DRV_LOG_

LogStart $LOG

#-----------------------------------------------------------#
# 関数
#-----------------------------------------------------------#
#-----------------------------------------------------------#
# メソッド名: check_continue_or_not
# 処理　: 処理を続けるかどうかをキーボード入力から判定する
# 引数　: なし
# 返り値: なし
#-----------------------------------------------------------#
check_continue_or_not() {
    read line
    if [ "$line" != "y" ] && [ "$line" != "yes" ] && [ "$line" != "Y" ] && [ "$line" != "YES" ] ; then
        echo
        echo "中止しました。"
	    rm -f $LOCK_FILE
	    sleep 3
	    exit 0
    fi
    echo
}

#-----------------------------------------------------------#
# main
#-----------------------------------------------------------#
echo ""
echo " ■ intel ドライバのインストール (Fedora 10 i386) "
echo ""
echo " intel 社の G45 チップセットを搭載した PC 用に"
echo " ドライバのインストールを行います。"
echo ""
echo " 注意"
echo "  intel の G45 チップセットが搭載されたモデルをお使いの"
echo "  場合にのみ実行してください。(例: 夏目坂モデル NORMAL) "
echo "  また、本プログラムは [カスタマイズの実行.sh] の後に実行"
echo "  してください。"
echo ""

LOCK_FILE=/var/lock/subsys/scustoma
if [ -f $LOCK_FILE ]; then
    echo " このスクリプトは、他のプロセスで実行中か、"
    echo " あるいは、前回の実行途中で中断した可能性があります。"
    echo 
    echo -n " 強制的に実行しますか? [y/n] "
else
    echo -n " 開始してもよろしいですか。[y/n] "
fi
touch $LOCK_FILE

# 処理を続けるかどうかを判定
check_continue_or_not

# G45 チップセットが搭載されているかどうかを調べる
return=`/sbin/lspci | grep -i "$G45_flg"`
if [ ! -n "$return" ]; then
    echo " lspci コマンドで PCI バスを調査しましたが、"
    echo " G45 チップセットは見つけられませんでした。"
    echo " このままインストールを行うと、"
    echo " 画面が正しく表示されなくなる可能性があります。"
    echo -n " インストールを続行しますか? [y/n] "

    # 処理を続けるかどうかを判定
    check_continue_or_not
fi

# xorg.conf のバックアップを取っておく
xconf="/etc/X11/xorg.conf"
xconf_bak="${xconf}.before-driver-setting"
if [ -f $xconf -a ! -f "${xconf_bak}" ] ; then
    \cp -pf "${xconf}" "${xconf_bak}"
fi

# ドライバのインストール
yum -y localupdate $DRV_DIR/*.rpm 2>&1 | tee -a $LOG
$SCRPT_HOME/check.sh
if [ $? -ne 0 ]; then
    echo
    echo "インストールできませんでした。"
    LogWrite $LOG "[エラー] intel ドライバのインストールに失敗"
else
    LogWrite $LOG " [OK] intel ドライバのインストールに成功"
	if [ -f "$xconf" ]; then
        # ドライバを有効にする
        ReplaceFile "s/vesa/intel/" $xconf

        ## Virtual行 を無効にする
    	#ReplaceFile "s/Virtual/#Virtual/" $xconf
	fi

        # yum.conf に exclude 設定を追加する
        yumconf=/etc/yum.conf
        exclude_pkg="kernel* libdrm* mesa* xorg-x11-drv-i810"
        grep "$exclude_pkg" $yumconf > /dev/null 2>&1
        if [ $? -ne 0 ]; then
            LogWrite $LOG " [OK] $yumconf に exclude 設定を追加"
            grep -e '^exclude=' $yumconf > /dev/null 2>&1
            if [ $? -eq 0 ]; then
                ReplaceFile "s/^(exclude=)/\1$exclude_pkg /" $yumconf
            else
                echo "exclude=$exclude_pkg" >> $yumconf
            fi
        fi

    # compiz を有効にする
    skel_conf="/etc/skel/.gconf/desktop/gnome/session/required_components/%gconf.xml"
	if [ -f "$skel_conf" ]; then
		ReplaceFile "s/metacity/compiz-gtk/" "$skel_conf"
		LogWrite $LOG " [OK] compiz を有効化 ($skel_conf)"
	fi    
    user_homes=$(cat /etc/passwd | grep -e "/home" -e "^root" | cut -d : -f 6) >> $LOG 2>&1 
    for aUserHome in $user_homes;
    do
		aConf="${aUserHome}/.gconf/desktop/gnome/session/required_components/%gconf.xml"
		if [ -f "$aConf" ]; then
			ReplaceFile "s/metacity/compiz-gtk/" "$aConf"
			LogWrite $LOG " [OK] compiz を有効化 ($aConf)"
    	fi
    done

    # 現ユーザ の compiz を有効にする
    su -c 'gconftool-2 -s --type=string "/desktop/gnome/session/required_components/windowmanager" "compiz-gtk"' "$LOGNAME"

    echo
    echo "インストールが完了しました。"
fi

echo
echo "Enter キーで再起動します。"
echo

read DUMMY

rm -f $LOCK_FILE
#-----------------------------------------------------------#
# 後処理
#-----------------------------------------------------------#
LogEnd $LOG

reboot


